@@ -1,29 +1,30 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-08 19:15:52 michl>
+# Last changed Time-stamp: <2018-01-10 00:28:46 mtw>
 
 package Bio::ViennaNGS::FeatureInterval;
 
-use version; our $VERSION = qv('0.17');
+use Bio::ViennaNGS;
 use namespace::autoclean;
 use Carp;
 use Moose;
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 has 'chromosome' => (
-		     is  => 'ro',
+		     is  => 'rw',
 		     isa => 'Str',
 		     required => 1,
 		     predicate => 'has_chromosome',
 	     );
 
 has 'start' => (
-		is      => 'ro',
+		is      => 'rw',
 		isa     => 'Int',
 		required => 1,
 		predicate => 'has_start',
 	       );
 
 has 'end' => (
-	      is      => 'ro',
+	      is      => 'rw',
 	      isa     => 'Int',
 	      required => 1,
 	      predicate => 'has_end',
@@ -46,6 +47,15 @@ sub BUILD { # call a parser method, depending on $self->instanceOf
   $self->_length($len);
 }
 
+sub dump {
+  my $self = shift;
+  print join("\t",
+	     $self->chromosome,
+	     $self->start,
+	     $self->end),
+	       "\n";
+}
+
 no Moose;
 
 1;
@@ -65,8 +75,8 @@ genomic intervals.
                                                  start => "1200",
                                                  end => "4300",
                                                 );
-
   my $len = $obj->_length();
+  $obj->dump();
 
 =head1 DESCRIPTION
 
@@ -77,6 +87,21 @@ for BED3 elements.
 
 This is the base class for L<Bio::ViennaNGS::MinimalFeature>.
 
+=head1 METHODS
+
+=over
+
+=item dump()
+
+Title   : dump
+
+Usage   : C<$obj-E<gt>dump;>
+
+Function: Print a tab-separated representation of C<$obj> (a BED3
+          line).
+
+=back
+
 =head1 SEE ALSO
 
 =over
@@ -93,7 +118,7 @@ Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2014-2018 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
